@@ -3,6 +3,7 @@ module Main (main) where
 import           Codec.Bz3
 import qualified Data.ByteString.Lazy as BSL
 import           System.Directory     (doesDirectoryExist, listDirectory)
+import           System.Random        (randomRIO)
 import           Test.Tasty           (defaultMain, testGroup)
 import           Test.Tasty.HUnit     (assertBool, testCase)
 
@@ -13,7 +14,9 @@ main = do
 
 roundtrip fp = testCase ("roundtrip " ++ fp) $ do
     contents <- BSL.readFile fp
-    let d = decompressFile contents
-        e = compressFile d
+    eb <- randomRIO (2::Int,8)
+    let bsz=2^eb*1024*1024
+        d = decompressFile contents
+        e = compressFile bsz d
         d1 = decompressFile e
     assertBool "doesn't error" (d1 `seq` True)
